@@ -1,6 +1,8 @@
 import re
 import math
 from typing import List
+import hashlib
+
 
 DATETIME_FMT = '%Y-%m-%d %H:%M:%S'
 DATE_FMT = '%Y-%m-%d'
@@ -37,3 +39,15 @@ def split_list(target_list: list, num_elements: int = 5) -> List[list]:
     """
     return [target_list[i * num_elements: (i + 1) * num_elements] for i in
             range(math.ceil(len(target_list) / num_elements))]
+
+
+def get_md5_value(src: str) -> str:
+    """
+    产生md5值。
+    :param src: 输入字符
+    :return: str， 输出md5字符串
+    """
+    myd5 = hashlib.md5()
+    myd5.update(src.encode("utf8"))
+    myd5digest = myd5.hexdigest()
+    return myd5digest
